@@ -1,15 +1,6 @@
 // Copyright (c) 2023 Yuki Kimoto
 // MIT License
 
-#ifdef __linux__
-  // Enable X/Open System Interfaces (SUSv4) functions and POSIX.1-2008 standard functions
-  #define _XOPEN_SOURCE 700
-
-  // Enable BSD and System V extensions
-  #define _DEFAULT_SOURCE
-#endif
-
-
 #include "spvm_native.h"
 
 #include <stdlib.h>
@@ -30,8 +21,8 @@ int32_t SPVM__Sys__Process__Constant__EXIT_FAILURE(SPVM_ENV* env, SPVM_VALUE* st
   stack[0].ival = EXIT_FAILURE;
   return 0;
 #else
-  env->die(env, stack, "EXIT_FAILURE is not defined in this system.", __func__, FILE_NAME, __LINE__);
-  return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
+  env->die(env, stack, "EXIT_FAILURE is not defined on this system", __func__, FILE_NAME, __LINE__);
+  return SPVM_NATIVE_C_CLASS_ID_ERROR_NOT_SUPPORTED;
 #endif
 
 }
@@ -42,8 +33,8 @@ int32_t SPVM__Sys__Process__Constant__EXIT_SUCCESS(SPVM_ENV* env, SPVM_VALUE* st
   stack[0].ival = EXIT_SUCCESS;
   return 0;
 #else
-  env->die(env, stack, "EXIT_SUCCESS is not defined in this system.", __func__, FILE_NAME, __LINE__);
-  return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
+  env->die(env, stack, "EXIT_SUCCESS is not defined on this system", __func__, FILE_NAME, __LINE__);
+  return SPVM_NATIVE_C_CLASS_ID_ERROR_NOT_SUPPORTED;
 #endif
 
 }
@@ -54,8 +45,8 @@ int32_t SPVM__Sys__Process__Constant__WNOHANG(SPVM_ENV* env, SPVM_VALUE* stack)
   stack[0].ival = WNOHANG;
   return 0;
 #else
-  env->die(env, stack, "WNOHANG is not defined in this system.", __func__, FILE_NAME, __LINE__);
-  return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
+  env->die(env, stack, "WNOHANG is not defined on this system", __func__, FILE_NAME, __LINE__);
+  return SPVM_NATIVE_C_CLASS_ID_ERROR_NOT_SUPPORTED;
 #endif
 
 }
@@ -66,8 +57,8 @@ int32_t SPVM__Sys__Process__Constant__WUNTRACED(SPVM_ENV* env, SPVM_VALUE* stack
   stack[0].ival = WUNTRACED;
   return 0;
 #else
-  env->die(env, stack, "WUNTRACED is not defined in this system.", __func__, FILE_NAME, __LINE__);
-  return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
+  env->die(env, stack, "WUNTRACED is not defined on this system", __func__, FILE_NAME, __LINE__);
+  return SPVM_NATIVE_C_CLASS_ID_ERROR_NOT_SUPPORTED;
 #endif
 
 }
@@ -78,8 +69,8 @@ int32_t SPVM__Sys__Process__Constant__WCONTINUED(SPVM_ENV* env, SPVM_VALUE* stac
   stack[0].ival = WCONTINUED;
   return 0;
 #else
-  env->die(env, stack, "WCONTINUED is not defined in this system.", __func__, FILE_NAME, __LINE__);
-  return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
+  env->die(env, stack, "WCONTINUED is not defined on this system", __func__, FILE_NAME, __LINE__);
+  return SPVM_NATIVE_C_CLASS_ID_ERROR_NOT_SUPPORTED;
 #endif
 
 }
@@ -90,8 +81,8 @@ int32_t SPVM__Sys__Process__Constant__PRIO_PROCESS(SPVM_ENV* env, SPVM_VALUE* st
   stack[0].ival = PRIO_PROCESS;
   return 0;
 #else
-  env->die(env, stack, "PRIO_PROCESS is not defined in this system.", __func__, FILE_NAME, __LINE__);
-  return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
+  env->die(env, stack, "PRIO_PROCESS is not defined on this system", __func__, FILE_NAME, __LINE__);
+  return SPVM_NATIVE_C_CLASS_ID_ERROR_NOT_SUPPORTED;
 #endif
 
 }
@@ -102,8 +93,8 @@ int32_t SPVM__Sys__Process__Constant__PRIO_USER(SPVM_ENV* env, SPVM_VALUE* stack
   stack[0].ival = PRIO_USER;
   return 0;
 #else
-  env->die(env, stack, "PRIO_USER is not defined in this system.", __func__, FILE_NAME, __LINE__);
-  return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
+  env->die(env, stack, "PRIO_USER is not defined on this system", __func__, FILE_NAME, __LINE__);
+  return SPVM_NATIVE_C_CLASS_ID_ERROR_NOT_SUPPORTED;
 #endif
 
 }
@@ -114,8 +105,8 @@ int32_t SPVM__Sys__Process__Constant__PRIO_PGRP(SPVM_ENV* env, SPVM_VALUE* stack
   stack[0].ival = PRIO_PGRP;
   return 0;
 #else
-  env->die(env, stack, "PRIO_PGRP is not defined in this system.", __func__, FILE_NAME, __LINE__);
-  return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
+  env->die(env, stack, "PRIO_PGRP is not defined on this system", __func__, FILE_NAME, __LINE__);
+  return SPVM_NATIVE_C_CLASS_ID_ERROR_NOT_SUPPORTED;
 #endif
 
 }
