@@ -1,30 +1,21 @@
 // Copyright (c) 2023 Yuki Kimoto
 // MIT License
 
-#ifdef __linux__
-  // Enable X/Open System Interfaces (SUSv4) functions and POSIX.1-2008 standard functions
-  #define _XOPEN_SOURCE 700
-
-  // Enable BSD and System V extensions
-  #define _DEFAULT_SOURCE
-#endif
-
-
 #include "spvm_native.h"
 #include "spvm_socket_util.h"
 
 #include <assert.h>
 
-static const char* FILE_NAME = "Sys/Socket/Sockaddr/Storage.c";
+const char* FILE_NAME = "Sys/Socket/Sockaddr/Storage.c";
 
 int32_t SPVM__Sys__Socket__Sockaddr__Storage__new(SPVM_ENV* env, SPVM_VALUE* stack) {
   
-  int32_t error_id = 0;
+  int32_t e = 0;
   
-  struct sockaddr_storage* socket_address = env->new_memory_block(env, stack, sizeof(struct sockaddr_storage));
+  struct sockaddr_storage* socket_address = env->new_memory_stack(env, stack, sizeof(struct sockaddr_storage));
 
-  void* obj_socket_address = env->new_pointer_object_by_name(env, stack, "Sys::Socket::Sockaddr::Storage", socket_address, &error_id, __func__, FILE_NAME, __LINE__);
-  if (error_id) { return error_id; }
+  void* obj_socket_address = env->new_pointer_object_by_name(env, stack, "Sys::Socket::Sockaddr::Storage", socket_address, &e, __func__, FILE_NAME, __LINE__);
+  if (e) { return e; }
   
   stack[0].oval = obj_socket_address;
   
@@ -39,7 +30,7 @@ int32_t SPVM__Sys__Socket__Sockaddr__Storage__DESTROY(SPVM_ENV* env, SPVM_VALUE*
   
   assert(socket_address);
   
-  env->free_memory_block(env, stack, socket_address);
+  env->free_memory_stack(env, stack, socket_address);
   env->set_pointer(env, stack, obj_socket_address, NULL);
   
   return 0;
@@ -67,7 +58,7 @@ int32_t SPVM__Sys__Socket__Sockaddr__Storage__set_ss_family(SPVM_ENV* env, SPVM_
   return 0;
 }
 
-int32_t SPVM__Sys__Socket__Sockaddr__Storage__size(SPVM_ENV* env, SPVM_VALUE* stack) {
+int32_t SPVM__Sys__Socket__Sockaddr__Storage__sizeof(SPVM_ENV* env, SPVM_VALUE* stack) {
   
   void* obj_self = stack[0].oval;
   
